Welcome to pytools's documentation!
===================================

.. toctree::
    :maxdepth: 2
    :caption: Contents:

    reference
    obj_array
    persistent_dict
    graph
    misc

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
